#!/bin/sh

LC_NUMERIC=en_US.UTF-8
export LC_NUMERIC

INPUTFILE=lan-csma.tr

if [ ! -f "$INPUTFILE" ]; then
	echo "ERROR: Can't find input file $INPUTFILE"
	exit 1
elif [ ! -s "$INPUTFILE" ]; then
	echo "ERROR: Empty input file $INPUTFILE"
	exit 1
fi

cat $INPUTFILE | gawk '
	BEGIN { generated = collisions = serviced = dropped = in_network = 0; } 
	{
		if ($1 == "r") { serviced++; }
		if ($1 == "c") { collisions++; }
		if ($1 == "d") { dropped++; }
		if ($1 == "h") { generated++; }
		if ($1 == "-") { in_network++; }
	}
	END {
		print "Generated Packets		:", generated;
		print "Packets transmitted 		:", in_network;
		print "Serviced Packets			:", serviced;
		print "Collisions			:", collisions;
		print "Dropped				:", dropped;
		print "Mean numb. of Collisions		:", collisions/in_network;
		print "Delivery Ratio (%)		:", serviced/generated
	}'

cat $INPUTFILE | gawk '
	{
		if ($1 == "h") { print 1000+$12,$2,"0h"; }
		if ($1 == "r") { print 1000+$12,$2,"3r"; }
	}' | sort | gawk '
	BEGIN { delay = pdelay = 0.0; count = count1 = p=0; }
	{
		count1++; 
		if (p == $1) {
			count++;
			delay += ($2 - pdelay);
		}
		p = $1;
		pdelay = $2;
	}
	END{
		delay *= 1000 / count;
		print "Mean packet delay (msec)	:", delay
	}'

